Struct amazon_sp_fulfillment_outbound::models::create_fulfillment_order_item::CreateFulfillmentOrderItem
source · [−]pub struct CreateFulfillmentOrderItem {
pub seller_sku: String,
pub seller_fulfillment_order_item_id: String,
pub quantity: i32,
pub gift_message: Option<String>,
pub displayable_comment: Option<String>,
pub fulfillment_network_sku: Option<String>,
pub per_unit_declared_value: Option<Box<Money>>,
pub per_unit_price: Option<Box<Money>>,
pub per_unit_tax: Option<Box<Money>>,
}Expand description
CreateFulfillmentOrderItem : Item information for creating a fulfillment order.
Fields
seller_sku: StringThe seller SKU of the item.
seller_fulfillment_order_item_id: StringA fulfillment order item identifier that the seller creates to track fulfillment order items. Used to disambiguate multiple fulfillment items that have the same SellerSKU. For example, the seller might assign different SellerFulfillmentOrderItemId values to two items in a fulfillment order that share the same SellerSKU but have different GiftMessage values.
quantity: i32The item quantity.
gift_message: Option<String>A message to the gift recipient, if applicable.
displayable_comment: Option<String>Item-specific text that displays in recipient-facing materials such as the outbound shipment packing slip.
fulfillment_network_sku: Option<String>Amazon’s fulfillment network SKU of the item.
per_unit_declared_value: Option<Box<Money>>per_unit_price: Option<Box<Money>>per_unit_tax: Option<Box<Money>>Implementations